<?php
/**
 * Brands widget
 *
 * Widget Name: Travel Gem Brands
 * Description: Display brand logos.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Brands widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Brands_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-brands',
			esc_html__( 'Travel Gem: Brands', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Display brand logos.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'brands' => array(
				'type'       => 'repeater',
				'label'      => esc_html__( 'Brands', 'travel-gem-pro' ),
				'item_name'  => esc_html__( 'Brand', 'travel-gem-pro' ),
				'item_label' => array(
					'selector'     => "[id*='brands-brand_title']",
					'update_event' => 'change',
					'value_method' => 'val',
					),
				'fields' => array(
					'brand_title' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Title', 'travel-gem-pro' ),
						),
					'brand_logo' => array(
						'type'     => 'media',
						'label'    => esc_html__( 'Logo', 'travel-gem-pro' ),
						'library'  => 'image',
						'fallback' => true,
						),
					'brand_url' => array(
						'type'  => 'link',
						'label' => esc_html__( 'URL', 'travel-gem-pro' ),
						),
					),
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => false,
				'fields' => array(
					'new_window' => array(
						'label'   => esc_html__( 'Open URL in new window', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => false,
						),
					),
				),
			);
	}
}

siteorigin_widget_register( 'travel-gem-brands', __FILE__, 'Travel_Gem_Brands_Widget' );
