<?php
/**
 * Intro widget
 *
 * Widget Name: Travel Gem Intro
 * Description: Displays introduction with an image.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Intro widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Intro_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-intro',
			esc_html__( 'Travel Gem: Intro', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays introduction with an image.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'left',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'intro' => array(
				'type'  => 'tinymce',
				'label' => esc_html__( 'Intro', 'travel-gem-pro' ),
				),
			'main_image' => array(
				'type'     => 'media',
				'label'    => esc_html__( 'Image', 'travel-gem-pro' ),
				'library'  => 'image',
				'choose'   => esc_html__( 'Choose Image', 'travel-gem-pro' ),
				'update'   => esc_html__( 'Set Image', 'travel-gem-pro' ),
				'fallback' => true,
				),
			'main_image_size' => array(
				'label'   => esc_html__( 'Image Size', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'large',
				'options' => travel_gem_get_image_sizes_options( false ),
				),
			'main_image_alignment' => array(
				'label'   => esc_html__( 'Image Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'left',
				'options' => travel_gem_get_alignment_options( array( 'left', 'right' ) ),
				),
			'more_button_text' => array(
				'label'   => esc_html__( 'More Button Text', 'travel-gem-pro' ),
				'type'    => 'text',
				'default' => esc_html__( 'Know More', 'travel-gem-pro' ),
				),
			'more_button_url' => array(
				'label'   => esc_html__( 'More Button URL', 'travel-gem-pro' ),
				'type'    => 'link',
				'default' => '#',
				),
			);
	}

}

siteorigin_widget_register( 'travel-gem-intro', __FILE__, 'Travel_Gem_Intro_Widget' );
