<?php
/**
 * Widget template
 *
 * @package Travel_Gem
 */

// Cycle data.
$slide_data = array(
	'fx'             => esc_attr( $instance['settings']['transition_effect'] ),
	'speed'          => absint( $instance['settings']['transition_duration'] ) * 1000,
	'pause-on-hover' => 'true',
	'loader'         => 'true',
	'log'            => 'false',
	'swipe'          => 'true',
	'auto-height'    => 'container',
	'slides'         => 'article',
);

if ( $instance['settings']['enable_autoplay'] ) {
	$slide_data['timeout'] = absint( $instance['settings']['transition_delay'] ) * 1000;
} else {
	$slide_data['timeout'] = 0;
}

$slide_data['pager-template'] = '<span class="pager-box"></span>';

$slide_attributes_text = '';

foreach ( $slide_data as $key => $item ) {

	$slide_attributes_text .= ' ';
	$slide_attributes_text .= ' data-cycle-' . esc_attr( $key );
	$slide_attributes_text .= '="' . esc_attr( $item ) . '"';
}

$overlay_class = ( true === $instance['settings']['enable_overlay'] ) ? 'overlay-enabled' : 'overlay-disabled' ;
?>

<div class="cycle-slideshow <?php echo esc_attr( $overlay_class ); ?>" <?php echo $slide_attributes_text; ?>>

	<?php if ( true === $instance['settings']['enable_arrow'] ) : ?>
		<div class="cycle-prev"><i class="fas fa-angle-left" aria-hidden="true"></i></div>
		<div class="cycle-next"><i class="fas fa-angle-right" aria-hidden="true"></i></div>
	<?php endif; ?>

	<?php if ( ! empty( $instance['slider'] ) ) : ?>
		<?php $cnt = 1; ?>
		<?php foreach ( $instance['slider'] as $slide ) : ?>
			<?php
			$image = siteorigin_widgets_get_attachment_image_src(
				$slide['slide_image'],
				'full',
				! empty( $slide['slide_image_fallback'] ) ? $slide['slide_image_fallback'] : false
			);
			if ( false === $image ) {
				continue;
			}
			?>
			<?php $class_text = ( 1 === $cnt ) ? 'first' : ''; ?>
			<article class="slide-item <?php echo esc_attr( $class_text ); ?>">
				<?php
				$link_open = '';
				$link_close = '';
				if ( ! empty( $slide['slide_url'] ) ) {
					$link_open = '<a href="' . sow_esc_url( $slide['slide_url'] ) . '">';
					$link_close = '</a>';
				}
				?>

				<?php if ( false !== $image ) : ?>
					<?php echo $link_open; ?><img src="<?php echo esc_url( $image[0] ); ?>" alt="" /><?php echo $link_close; ?>
				<?php endif; ?>

				<?php if ( true === $instance['settings']['enable_caption'] ) : ?>
					<?php $caption_class = 'text-align' . esc_attr( $slide['caption_alignment'] ); ?>
					<div class="cycle-caption <?php echo esc_attr( $caption_class ); ?>">
						<div class="caption-wrap">
							<?php if ( ! empty( $slide['slide_title'] ) ) : ?>
								<?php
								$slide_title_color = ( ! empty( $slide['slide_title_color'] ) ) ? $slide['slide_title_color'] : '';
								$slide_title_style = '';
								if ( ! empty( $slide_title_color ) ) {
									$slide_title_style .= 'color:' . esc_attr( $slide_title_color );
								}
								?>
								<?php if ( empty( $slide['slide_url'] ) ) : ?>
									<h3 style="<?php echo esc_attr( $slide_title_style ); ?>"><?php echo esc_html( $slide['slide_title'] ); ?></h3>
								<?php else : ?>
									<h3><a href="<?php echo sow_esc_url( $slide['slide_url'] ); ?>" style="<?php echo esc_attr( $slide_title_style ); ?>"><?php echo esc_html( $slide['slide_title'] ); ?></a></h3>
								<?php endif; ?>
							<?php endif; ?>

							<?php if ( ! empty( $slide['slide_subtitle'] ) ) : ?>
								<?php
								$slide_subtitle_color = ( ! empty( $slide['slide_subtitle_color'] ) ) ? $slide['slide_subtitle_color'] : '';
								$slide_subtitle_style = '';
								if ( ! empty( $slide_subtitle_color ) ) {
									$slide_subtitle_style .= 'color:' . esc_attr( $slide_subtitle_color );
								}
								?>
								<div class="slide-caption-text" style="<?php echo esc_attr( $slide_subtitle_style ); ?>">
									<?php echo wp_kses_post( wpautop( $slide['slide_subtitle'] ) ); ?>
								</div><!-- .slide-caption-text -->

							<?php endif; ?>

							<?php if ( ( ! empty( $slide['primary_button_text'] ) && ! empty( $slide['primary_button_url'] ) ) || ! empty( $slide['secondary_button_text'] ) && ! empty( $slide['secondary_button_url'] ) ) : ?>
								<div class="slider-buttons">
									<?php if ( ! empty( $slide['primary_button_text'] ) && ! empty( $slide['primary_button_url'] ) ) : ?>
										<a class="custom-button" href="<?php echo sow_esc_url( $slide['primary_button_url'] ); ?>"><?php echo esc_html( $slide['primary_button_text'] ); ?></a>
									<?php endif; ?>
									<?php if ( ! empty( $slide['secondary_button_text'] ) && ! empty( $slide['secondary_button_url'] ) ) : ?>
										<a class="custom-button custom-secondary-button" href="<?php echo sow_esc_url( $slide['secondary_button_url'] ); ?>"><?php echo esc_html( $slide['secondary_button_text'] ); ?></a>
									<?php endif; ?>
								</div><!-- .slider-buttons -->
							<?php endif; ?>
						</div><!-- .caption-wrap -->
					</div><!-- .cycle-caption -->
				<?php endif; ?>
			</article><!-- .slide-item -->
			<?php $cnt++; ?>
		<?php endforeach; ?>

		<?php if ( true === $instance['settings']['enable_pager'] ) : ?>
			<div class="cycle-pager"></div>
		<?php endif; ?>

	<?php endif; ?>
</div><!-- .cycle-slideshow -->
