<?php
/**
 * Stats widget
 *
 * Widget Name: Travel Gem Stats
 * Description: Displays stats counter.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Stats widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Stats_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-stats',
			esc_html__( 'Travel Gem: Stats', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays stats counter.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'stats' => array(
				'type'       => 'repeater',
				'label'      => esc_html__( 'Stats', 'travel-gem-pro' ),
				'item_name'  => esc_html__( 'Stat', 'travel-gem-pro' ),
				'item_label' => array(
					'selector'     => "[id*='stats-stat_title']",
					'update_event' => 'change',
					'value_method' => 'val',
					),
				'fields' => array(
					'stat_title' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Title', 'travel-gem-pro' ),
						),
					'stat_number' => array(
						'type'  => 'number',
						'label' => esc_html__( 'Number', 'travel-gem-pro' ),
						),
					'stat_icon' => array(
						'type'  => 'icon',
						'label' => esc_html__( 'Icon', 'travel-gem-pro' ),
						),
					),
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => false,
				'fields' => array(
					'post_column' => array(
						'label'   => esc_html__( 'Number of Columns', 'travel-gem-pro' ),
						'type'    => 'select',
						'default' => 4,
						'options' => travel_gem_get_numbers_dropdown_options( 3, 4 ),
						),
					'stat_title_color' => array(
						'type'    => 'color',
						'label'   => esc_html__( 'Stat Title Color', 'travel-gem-pro' ),
						'default' => '#000',
						),
					'stat_number_color' => array(
						'type'    => 'color',
						'label'   => esc_html__( 'Stat Number Color', 'travel-gem-pro' ),
						'default' => '#4F5D75',
						),
					'stat_icon_color' => array(
						'type'    => 'color',
						'label'   => esc_html__( 'Stat Icon Color', 'travel-gem-pro' ),
						'default' => '#FFCC07',
						),
					),
				),
			);
	}

	/**
	 * Less variables.
	 *
	 * @since 1.0.0
	 *
	 * @param array $instance Widget instance.
	 * @return array Less variables.
	 */
	function get_less_variables( $instance ) {
		if ( empty( $instance ) ) {
			return array();
		}

		return array(
			'stat_title_color'  => $instance['settings']['stat_title_color'],
			'stat_number_color' => $instance['settings']['stat_number_color'],
			'stat_icon_color'   => $instance['settings']['stat_icon_color'],
		);
	}

	/**
	 * Initialize.
	 *
	 * @since 1.0.0
	 */
	function initialize() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
		$this->register_frontend_scripts(
			array(
				array(
					'jquery-waypoints',
					get_template_directory_uri() . '/third-party/waypoints/jquery.waypoints' . $min . '.js',
					array( 'jquery' ),
					'4.0.1',
					),
				array(
					'jquery-counterup',
					get_template_directory_uri() . '/third-party/counterup/jquery.counterup' . $min . '.js',
					array( 'jquery' ),
					'2.1.0',
					),
				)
		);
	}

}

siteorigin_widget_register( 'travel-gem-stats', __FILE__, 'Travel_Gem_Stats_Widget' );
